//Copyright © 2015-2017, Verizon and/or its Licensors. All rights reserved.

#import "PCResourceAPIParams.h"
#import "PCContact.h"

/*!
 * PCContactBaseAPIParams stores all the parameters required for email or phone number or address.
 */
@interface PCContactBaseAPIParams : NSObject
/*!
 * The type of contact either email or phone number or address or IM. Supported value for  email type('business','personal','other), phone number type('assistant','businessfax','business','callback','car','companymain','homefax','home','mobile','otherfax','pager','primaryfax','primary','radio','school','telex','ttydd','videophone','voipphone','other') , address type('home','business','personal','primary','other') , IM type('aim','icq','yahoo','google','skype','jabber','msn','other') (optional)
 */
@property (nonatomic, copy) NSString *type;

/*!
 * When combined with 'type', provides a unique identifier for the entry. (optional)
 */
@property (nonatomic, copy) NSNumber* indx;

/*!
 * For sorting. Lower numbers indicate a higher preference. (optional)
 */
@property (nonatomic, copy) NSNumber* preference;

@end

/*!
 * PCTelContactAPIParams stores all the parameters required to telephone.
 */
@interface PCTelContactAPIParams : PCContactBaseAPIParams
/*!
 * Telephone number. (optional)
 */
@property (nonatomic, copy) NSNumber* number;

@end

/*!
 * PCEmailContactAPIParams stores all the parameters required to email.
 */
@interface PCEmailContactAPIParams : PCContactBaseAPIParams
/*!
 * Email address. (optional)
 */
@property (nonatomic, copy) NSString* address;

@end

/*!
 * PCIMContactAPIParams stores all the parameters required to IM.
 */
@interface PCIMContactAPIParams : PCContactBaseAPIParams
/*!
 * IM contact string. (optional)
 */
@property (nonatomic, copy) NSString* address;

@end

/*!
 * PCAddressContactAPIParams stores all the parameters required to address.
 */
@interface PCAddressContactAPIParams : PCContactBaseAPIParams

/*!
 * Contacts's city name. (optional)
 */
@property (nonatomic ,copy) NSString *city;

/*!
 * Contacts's country name. (optional)
 */
@property (nonatomic ,copy) NSString *country;

/*!
 * Contacts's pobox name. (optional)
 */
@property (nonatomic ,copy) NSString *pobox;

/*!
 * Contacts's street name. (optional)
 */
@property (nonatomic ,copy) NSString *street;

/*!
 * Contacts's zipcode name. (optional)
 */
@property (nonatomic ,copy) NSString *zipcode;

/*!
 * Contacts's apartment name. (optional)
 */
@property (nonatomic ,copy) NSString *apartment;

/*!
 * Contacts's state name. (optional)
 */
@property (nonatomic ,copy) NSString *state;

@end

/*!
 * PCCreateContactAPIParams stores all the parameters required to create a contact.
 */

@interface PCCreateContactAPIParams : PCResourceAPIParams

/*!
 * Contact's first name. (optional)
 */
@property (nonatomic, copy) NSString *firstName;

/*!
 * Contact's last name. (optional)
 */
@property (nonatomic, copy) NSString *lastName;

/*!
 * Contact's middle name. (optional)
 */
@property (nonatomic, copy) NSString *middleName;

/*!
 * Contact's name prefix. (optional)
 */
@property (nonatomic, copy) NSString *namePrefix;

/*!
 * Contact's name suffix. (optional)
 */
@property (nonatomic, copy) NSString *nameSuffix;

/*!
 * Contact's nick name. (optional)
 */
@property (nonatomic, copy) NSString *nickname;

/*!
 * Contacts's birth date in the format YYYY-MM-DD. (optional)
 */
@property (nonatomic, copy) NSString *birthday;


/*!
 * Contacts's anniversary date in the format YYYY-MM-DD. (optional)
 */
@property (nonatomic, copy) NSString *anniversary;

/*!
 * Contacts's spouse name. (optional)
 */
@property (nonatomic, copy) NSString *spouse;

/*!
 * Contacts's children name. (optional)
 */
@property (nonatomic, copy) NSString *children;

/*!
 * Contacts's company name. (optional)
 */
@property (nonatomic, copy) NSString *orgname;
/*!
 * Contacts's company department. (optional)
 */
@property (nonatomic, copy) NSString *orgUnit;
/*!
 * Contacts's job titile. (optional)
 */
@property (nonatomic, copy) NSString *jobTitle;
/*!
 * Contacts's profession. (optional)
 */
@property (nonatomic, copy) NSString *profession;
/*!
 * Contacts's assistant name. (optional)
 */
@property (nonatomic, copy) NSString *assistant;

/*!
 * Contacts's gender. (optional)
 */
@property (nonatomic, copy) NSString *gender;

/*!
 * Contacts's relationship with the person. (optional)
 */
@property (nonatomic, copy) NSString *relationship;

/*!
 *Contacts's marital status. (optional)
 */
@property (nonatomic, copy) NSString *maritalStatus;

/*!
 *Origin of the contact. (optional)
 */
@property (nonatomic, copy) NSString *source;

/*!
 *Arbitrary text associated with this contact . (optional)
 */
@property (nonatomic, copy) NSString *note;

/*!
 * Marked true for emergency contacts. (optional)
 */
@property (nonatomic, assign) BOOL incaseOfEmergency;

/*!
 * Marked true for favorite contacts. (optional)
 */
@property (nonatomic, assign) BOOL favorite;

/*!
 * List of contact's telephone numbers, Which hold PCTelContactAPIParams object.
 */
@property (nonatomic, copy) NSArray *telephone;

/*!
 * List of contact's emails address, Which hold PCEmailContactAPIParams object.
 */
@property (nonatomic, copy) NSArray *email;

/*!
 * List of contact's addresses, Which hold PCAddressContactAPIParams object.
 */
@property (nonatomic, copy) NSArray *address;

/*!
 * List of contact's IM addresses, Which hold PCIMContactAPIParams object.
 */
@property (nonatomic, copy) NSArray *im;

/*!
 * Call this method to initialize PCCreateContactAPIParams object with values.
 * \param contact stores all the details of a contact. Which used to set value in PCCreateContactAPIParams object.
 */
- (id)initWithPCContact:(PCContact *)contact;

@end
